"""
TN-NT Templates init
"""

# Standard Library
from importlib import metadata

__version__ = metadata.version("tnnt-templates")
__title__ = "Terra Nanotech Alliance Auth Template Overrides"

del metadata
