{% load tnnt_template_tags %}
{% load static %}
{% load i18n %}
{% load auth_notifications %}
<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="description" content="">
        <meta name="author" content="{{ TNNT_TEMPLATE_ENTITY_NAME }}">

        {% include 'allianceauth/icons.html' %}

        <title>{% block title %}{% block page_title %}{% endblock page_title %} » {{ SITE_NAME }}{% endblock title %}</title>

        <link rel="stylesheet" href="{% static 'tnnt_templates/css/theme/terra-nanotech/v3/css/bootstrap.min.css' %}">
        {% include 'bundles/fontawesome.html' %}

        <link rel="stylesheet" href="{% tnnt_static 'tnnt_templates/css/fonts.min.css' %}">
        <link rel="stylesheet" href="{% static 'tnnt_templates/libs/fira-code/6.2.0/fira_code.min.css' %}">
        <link rel="stylesheet" href="{% static 'tnnt_templates/libs/highlight-js/11.01/styles/default.min.css' %}">
        <link rel="stylesheet" href="{% tnnt_static 'tnnt_templates/css/terra-nanotech-defaults.min.css' %}">
        <link rel="stylesheet" href="{% tnnt_static 'tnnt_templates/css/terra-nanotech.min.css' %}">

        {% block extra_css %}{% endblock extra_css %}
        <link rel="stylesheet" href="{% tnnt_static 'tnnt_templates/css/community-app-fixes.min.css' %}">

        {% if NIGHT_MODE %}
            <link rel="stylesheet" href="{% tnnt_static 'tnnt_templates/css/terra-nanotech-dark-mode.min.css' %}">
        {% endif %}
    </head>

    <body class="{% if NIGHT_MODE %}template-dark-mode{% else %}template-light-mode{% endif %}">
            <div class="alliance-auth-background"></div>
            <div class="alliance-auth-content">
                <!-- Navigation -->
                {% include 'allianceauth/top-menu.html' %}

                <div class="clearfix site-body-wrapper {% if not user.is_authenticated %}site-body-wrapper-public-view{% endif %}">
                    {% if user.is_authenticated %}
                        {% include 'allianceauth/side-menu.html' %}
                    {% endif %}

                    <div class="{% if user.is_authenticated %}col-sm-10{% else %}col-sm-12{% endif %} auth-page-content">
                        {% if user.is_authenticated %}
                            {% include 'allianceauth/messages.html' %}
                        {% endif %}

                        {% block content %}
                        {% endblock content %}
                    </div>
                </div>
            </div>


        {% include 'bundles/bootstrap-js.html' %}
        {% include 'bundles/jquery-visibility-js.html' %}

        {% if user.is_authenticated %}
            <script>
                const notificationUPdateSettings = {
                    notificationsListViewUrl: "{% url 'notifications:list' %}",
                    notificationsRefreshTime: "{% notifications_refresh_time %}",
                    userNotificationsCountViewUrl: "{% url 'notifications:user_notifications_count' request.user.pk %}"
                };
            </script>
            {% include 'bundles/refresh-notifications-js.html' %}
        {% endif %}

        <script src="{% static 'tnnt_templates/libs/highlight-js/11.01/highlight.min.js' %}"></script>
        <script src="{% tnnt_static 'tnnt_templates/javascript/terra-nanotech.min.js' %}"></script>

        {% block extra_javascript %}
        {% endblock extra_javascript %}

        <script>
            {% block extra_script %}
            {% endblock extra_script %}
        </script>
    </body>
</html>
